==> haskell-scotty-0.22-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-scotty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 scotty
version:              0.22
visibility:           public
id:                   scotty-0.22-Krw7NlVKhN2JONPpF7hddh
key:                  scotty-0.22-Krw7NlVKhN2JONPpF7hddh
license:              BSD-3-Clause
copyright:            (c) 2012-Present, Andrew Farmer and the Scotty contributors
maintainer:           The Scotty maintainers
author:               Andrew Farmer <xichekolas@gmail.com>
stability:            experimental
homepage:             https://github.com/scotty-web/scotty
synopsis:
    Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp

description:
    A Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp.

    @
    &#123;-&#35; LANGUAGE OverloadedStrings &#35;-&#125;

    import Web.Scotty

    main = scotty 3000 $
    &#32;&#32;get &#34;/:word&#34; $ do
    &#32;&#32;&#32;&#32;beam <- pathParam &#34;word&#34;
    &#32;&#32;&#32;&#32;html $ mconcat [&#34;&#60;h1&#62;Scotty, &#34;, beam, &#34; me up!&#60;/h1&#62;&#34;]
    @


    Scotty is the cheap and cheerful way to write RESTful, declarative web applications.

    * A page is as simple as defining the verb, url pattern, and Text content.

    * It is template-language agnostic. Anything that returns a Text value will do.

    * Conforms to WAI Application interface.

    * Uses very fast Warp webserver by default.

    As for the name: Sinatra + Warp = Scotty.

    [WAI] <http://hackage.haskell.org/package/wai>

    [Warp] <http://hackage.haskell.org/package/warp>

category:             Web
abi:                  333363c4b08fa9edf12fb23bf70dd571
exposed:              True
exposed-modules:
    Web.Scotty Web.Scotty.Cookie Web.Scotty.Internal.Types
    Web.Scotty.Trans Web.Scotty.Trans.Strict

hidden-modules:
    Web.Scotty.Action Web.Scotty.Body Web.Scotty.Route
    Web.Scotty.Trans.Lazy Web.Scotty.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/scotty-0.22
library-dirs:         /usr/lib/ghc-9.4.8/site-local/scotty-0.22
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/scotty-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-scotty
hs-libraries:         HSscotty-0.22-Krw7NlVKhN2JONPpF7hddh
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh base-4.17.2.1
    blaze-builder-0.4.4-9TwQ27zteac6dzdX8WGk7W bytestring-0.11.5.3
    case-insensitive-1.2.1.0-1RHeXy1S6Rm5Spie3OUbmD
    cookie-0.4.6-GZOZqzUDn152OuhEYvht8s
    data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb exceptions-0.10.5
    http-types-0.12.4-AKSPjJIqePQLPw819bUb23
    monad-control-1.0.3.1-98IgahJbhzB7hRizmXBhN1 mtl-2.2.2
    network-3.1.4.0-L5Z9Li45X29DmnCadSsbZW
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    resourcet-1.2.6-7pcZOXyYp3bA9FS4E6qwzr stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-8n2vEXi35k9DcuZkJZ3K5I
    unliftio-0.2.25.1-LsEvxp1Gk65DV9LxodxxKS
    wai-3.2.4-5NCCbE2MlhR8uTC9MRfmrk
    wai-extra-3.1.17-6RX4PqKkXOi3aJ1coHVHZv
    warp-3.3.30-KQjY84HGmJ9K67X5iCAWhA

haddock-interfaces:   /usr/share/doc/haskell-scotty/html/scotty.haddock
haddock-html:         /usr/share/doc/haskell-scotty/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-scotty-0.22-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-scotty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 scotty
version:              0.22
visibility:           public
id:                   scotty-0.22-5z8aFBqYR5cFMe1Jnsx3i1
key:                  scotty-0.22-5z8aFBqYR5cFMe1Jnsx3i1
license:              BSD-3-Clause
copyright:            (c) 2012-Present, Andrew Farmer and the Scotty contributors
maintainer:           The Scotty maintainers
author:               Andrew Farmer <xichekolas@gmail.com>
stability:            experimental
homepage:             https://github.com/scotty-web/scotty
synopsis:
    Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp

description:
    A Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp.

    @
    &#123;-&#35; LANGUAGE OverloadedStrings &#35;-&#125;

    import Web.Scotty

    main = scotty 3000 $
    &#32;&#32;get &#34;/:word&#34; $ do
    &#32;&#32;&#32;&#32;beam <- pathParam &#34;word&#34;
    &#32;&#32;&#32;&#32;html $ mconcat [&#34;&#60;h1&#62;Scotty, &#34;, beam, &#34; me up!&#60;/h1&#62;&#34;]
    @


    Scotty is the cheap and cheerful way to write RESTful, declarative web applications.

    * A page is as simple as defining the verb, url pattern, and Text content.

    * It is template-language agnostic. Anything that returns a Text value will do.

    * Conforms to WAI Application interface.

    * Uses very fast Warp webserver by default.

    As for the name: Sinatra + Warp = Scotty.

    [WAI] <http://hackage.haskell.org/package/wai>

    [Warp] <http://hackage.haskell.org/package/warp>

category:             Web
abi:                  1d13b5d65551016c47ee62096742dc29
exposed:              True
exposed-modules:
    Web.Scotty Web.Scotty.Cookie Web.Scotty.Internal.Types
    Web.Scotty.Trans Web.Scotty.Trans.Strict

hidden-modules:
    Web.Scotty.Action Web.Scotty.Body Web.Scotty.Route
    Web.Scotty.Trans.Lazy Web.Scotty.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/scotty-0.22
library-dirs:         /usr/lib/ghc-9.4.8/site-local/scotty-0.22
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/scotty-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-scotty
hs-libraries:         HSscotty-0.22-5z8aFBqYR5cFMe1Jnsx3i1
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh base-4.17.2.1
    blaze-builder-0.4.4-9TwQ27zteac6dzdX8WGk7W bytestring-0.11.5.3
    case-insensitive-1.2.1.0-1RHeXy1S6Rm5Spie3OUbmD
    cookie-0.4.6-GZOZqzUDn152OuhEYvht8s
    data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb exceptions-0.10.5
    http-types-0.12.4-AKSPjJIqePQLPw819bUb23
    monad-control-1.0.3.1-98IgahJbhzB7hRizmXBhN1 mtl-2.2.2
    network-3.1.4.0-L5Z9Li45X29DmnCadSsbZW
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    resourcet-1.2.6-7pcZOXyYp3bA9FS4E6qwzr stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-8n2vEXi35k9DcuZkJZ3K5I
    unliftio-0.2.25.1-LsEvxp1Gk65DV9LxodxxKS
    wai-3.2.4-5NCCbE2MlhR8uTC9MRfmrk
    wai-extra-3.1.17-GxD8yd34eL3CJXZz7xIhMh
    warp-3.3.30-yQgzpV7zRBGIgcxEF5wSw

haddock-interfaces:   /usr/share/doc/haskell-scotty/html/scotty.haddock
haddock-html:         /usr/share/doc/haskell-scotty/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
